/**
 * apeman bud for settings
 * @memberof module:apeman-bud-settings/lib
 * @function setup
 * @param {object} params - Template params.
 * @returns {object} - Coz bud configuration.
 */

"use strict";

const argx = require('argx'),
    stringcase = require('stringcase'),
    assert = require('assert'),
    _tmpl = require('./_tmpl');

/** @lends setup */
function setup(params) {
    let args = argx(arguments);
    params = args.shift('object') || {};

    let name = params.name;

    assert(name, 'params.name is required.');

    return [].concat(name).map(name => {

        let tmpl = _tmpl(name);
        return {
            force: false,
            mode: '644',
            path: `${stringcase.spinalcase(name)}.setting.json`,
            tmpl: tmpl,
            data: {
                name: name,
                params: params
            }
        }
    });
}

setup.ui = function (params) {
    params = params || {};
    params.ui = true;
    return setup(params);
};

setup.react = function (params) {
    params = params || {};
    params.react = true;
    params.middlewares = params.middlewares || [
            'props'
        ];
    params.routes = params.routes || [
            'index',
            'other',
            'onetime'
        ];
    return setup(params);
};


setup.api = function (params) {
    params = params || {};
    params.api = true;
    params.base = '/api';
    params.routes = params.routes || [
            'captcha',
            'user',
            'verify',
            'profile',
            'recover',
            'sign'
        ];
    return setup(params);
};

setup.adminApi = function (params) {
    params = params || {};
    params.adminApi = true;
    params.base = '/api';
    params.routes = params.routes || [
            'user',
            'sign'
        ];
    return setup(params);
};

module.exports = setup;
