/**
 * Test case for setup.
 * Runs with mocha.
 */
"use strict";

const setup = require('../lib/setup.js'),
    coz = require('coz'),
    path = require('path'),
    assert = require('assert');

describe('setup', () => {

    let tmpDir = `${__dirname}/../tmp`;

    before((done) => {
        done();
    });

    after((done) => {
        done();
    });


    it('Render asset', (done) => {
        let bud = setup({
            name: 'asset'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, bud.path);
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });

    });

    it('Render route', (done) => {
        let bud = setup({
            name: 'route'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, bud.path);
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });

    });

    it('Render api route', (done) => {
        let bud = setup.api({
            name: 'route'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, bud.path);
            bud.mkdirp = true;
            bud.force = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });

    });


    it('Render page', (done) => {
        let bud = setup({
            name: 'page'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, bud.path);
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });

    });


    it('Render routes', (done) => {
        let bud = setup({
            name: 'route',
            routes: [
                'hoge',
                'fuge'
            ]
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, bud.path);
            bud.force = true;
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });

    });


    it('Render symlink', (done) => {
        let bud = setup({
            name: 'symlink'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, bud.path);
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });

    });

    it('Render color', (done) => {
        let bud = setup({
            name: 'color'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, bud.path);
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });

    });

    it('Render redirect', (done) => {
        let bud = setup({
            name: 'redirect'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, bud.path);
            bud.force = true;
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });

    });


    it('Render react middleware', (done) => {
        let bud = setup.react({
            name: 'middleware'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, "react", bud.path);
            bud.force = true;
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render react route', (done) => {
        let bud = setup.react({
            name: 'route'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, "react", bud.path);
            bud.force = true;
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });

    it('Render api route', (done) => {
        let bud = setup.api({
            name: 'route'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, "api", bud.path);
            bud.force = true;
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });


    it('Render admin api route', (done) => {
        let bud = setup.adminApi({
            name: 'route'
        });

        [].concat(bud).forEach((bud) => {
            bud.path = path.join(tmpDir, "admin-api", bud.path);
            bud.force = true;
            bud.mkdirp = true;
        });

        coz.render(bud, (err) => {
            assert.ifError(err);
            done();
        });
    });


});

